@@ -19,9 +19,9 @@
 #'     (\href{https://orcid.org/0000-0002-0750-061X}{ORCID})
 #'
 #' @importFrom nanonext call_aio context is_nul_byte recv_ctx request send_aio
-#'     send_ctx socket stop_aio unresolved .mirai_scm
+#'     send_ctx socket stop_aio unresolved
 #' @importFrom stats runif
-#' @importFrom utils .DollarNames
+#' @useDynLib mirai, .registration = TRUE
 #'
 #' @docType package
 #' @name mirai-package
@@ -31,6 +31,7 @@ NULL
 .onLoad <- function(libname, pkgname) {
   daemons <- daemons()
   daemons <<- daemons
+  .miraisysname <<- .subset2(Sys.info(), "sysname")
   invisible()
 }
 
@@ -45,3 +46,5 @@ nanonext::is_nul_byte
 #' @export
 nanonext::unresolved
 
+.miraisysname <- NULL
+
