@@ -5,6 +5,6 @@ m <- eval_mirai({
   q / m
 }, m = 2L, n = 3L)
 invisible(inherits(call_mirai(m), "mirai") || stop())
-invisible(m$value == 3L || stop())
+invisible(m$data == 3L || stop())
 invisible(identical(call_mirai(m), m) || stop())
 
